import Keycloak from 'keycloak-js';
import { useEffect, useState } from 'react';

const keycloakConfig = {
    url: process.env.KEYCLOAK_URL as string,
    realm: process.env.KEYCLOAK_REALM as string,
    clientId: process.env.KEYCLOAK_CLIENT as string,
};

const kc = new Keycloak(keycloakConfig);

let keycloakInitialized = false; // Prevent multiple initializations

const initKeycloak = async () => {
    if (!keycloakInitialized) {
        keycloakInitialized = true;
        return kc.init({
            onLoad: 'check-sso',
            silentCheckSsoRedirectUri: window.location.origin + "/silent-check-sso.html",
            checkLoginIframe: false,
            pkceMethod: 'S256',
        });
    }
    return kc.authenticated ?? false;
};

export function useKeycloakAuth() {
    const [authenticated, setAuthenticated] = useState<boolean | null>(null);

    useEffect(() => {
        initKeycloak().then(auth => setAuthenticated(auth));

        // Ensure event listeners are only set once
        if (!kc.onTokenExpired) {
            kc.onTokenExpired = () => kc.updateToken().then(() => setAuthenticated(true));
        }

        kc.onAuthSuccess = () => setAuthenticated(true);
        kc.onAuthError = () => setAuthenticated(false);
        kc.onAuthLogout = () => setAuthenticated(false);
    }, []);

    return { authenticated, keycloak: kc };
}
